@@ -11,7 +11,7 @@ sub iter_jobs_summary {
     my $jobref     = shift;
 
     my $submission_id = $submission->{uuid};
-    my $table         = $self->build_table($submission);
+    my $table         = $self->build_table($submission, $submission_id);
     $table->setCols(
         [ 'JobName', 'Complete', 'Running', 'Success', 'Fail', 'Total' ] );
 
